@@ -119,6 +119,8 @@ class S3BaseStorage(AbstractStorage):
 
         self.executor = concurrent.futures.ThreadPoolExecutor(int(config.concurrent_transfers))
 
+        self.read_timeout = int(config.read_timeout) if 'read_timeout' in dir(config) and config.read_timeout else None
+
         super().__init__(config)
 
     def connect(self):
@@ -137,7 +139,8 @@ class S3BaseStorage(AbstractStorage):
             signature_version='v4',
             tcp_keepalive=True,
             max_pool_connections=max_pool_size,
-            read_timeout=int(self.config.read_timeout),
+            read_timeout=self.read_timeout,
+            s3={'addressing_style': self.config.s3_addressing_style},
         )
         if self.credentials.access_key_id is not None:
             self.s3_client = boto3.client(
@@ -185,6 +188,7 @@ class S3BaseStorage(AbstractStorage):
     def _make_transfer_config(self, config):
 
         transfer_max_bandwidth = config.transfer_max_bandwidth or None
+        multipart_chunksize = config.multipart_chunksize or None
 
         # we hard-code this one because the parallelism is for now applied to chunking the files
         transfer_config = {
@@ -194,6 +198,8 @@ class S3BaseStorage(AbstractStorage):
         if transfer_max_bandwidth is not None:
             transfer_config['max_bandwidth'] = AbstractStorage._human_size_to_bytes(transfer_max_bandwidth)
 
+        if multipart_chunksize is not None:
+            transfer_config['multipart_chunksize'] = AbstractStorage._human_size_to_bytes(multipart_chunksize)
         return TransferConfig(**transfer_config)
 
     @staticmethod
